# gFunctionLibrary
A submodule of the GLHE Design Tool, containing libraries of g-functions, access and accurate interpolation

The libraries of g-functions available are the following:

- [x] Rectangles (including lines)
- [x] Open rectangles
- [ ] L configuration
- [x] U configuration
- [x] Zoned rectangles

# Documentation
See the documentation at <a href="https://gfunctionlibrary.readthedocs.io/en/latest/" target="_blank">ReadTheDocs</a>